==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/WebGroupByRowTemplateContextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowTemplateContextDescriptionMetadata } from "./WebGroupByRowTemplateContextDescriptionMetadata";
import { WebGroupByRowTemplateContextEventArgsDescription } from "./WebGroupByRowTemplateContextEventArgsDescription";
/**
 * @hidden
 */
export let WebGroupByRowTemplateContextEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowTemplateContextEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a == null) {
                WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowTemplateContextEventArgsDescriptionMetadata.c(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
            }
            if (a.j(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
            WebGroupByRowTemplateContextDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowTemplateContextEventArgs");
            a.item("Detail", "ExportedType:WebGroupByRowTemplateContext");
        }
        static d(a) {
            WebGroupByRowTemplateContextEventArgsDescriptionMetadata.b(a);
            a.aa("WebGroupByRowTemplateContextEventArgs", () => new WebGroupByRowTemplateContextEventArgsDescription());
            a.z("WebGroupByRowTemplateContextEventArgs", WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
        }
    }
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByRowTemplateContextEventArgsDescriptionMetadata, 'WebGroupByRowTemplateContextEventArgsDescriptionMetadata');
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebGroupByRowTemplateContextEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebGroupByRowTemplateContextDescriptionMetadata } from "./WebGroupByRowTemplateContextDescriptionMetadata";
import { WebGroupByRowTemplateContextEventArgsDescription } from "./WebGroupByRowTemplateContextEventArgsDescription";
/**
 * @hidden
 */
export let WebGroupByRowTemplateContextEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebGroupByRowTemplateContextEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a == null) {
                WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebGroupByRowTemplateContextEventArgsDescriptionMetadata.c(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
            }
            if (a.k(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
            WebGroupByRowTemplateContextDescriptionMetadata.d(a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:GroupByRowTemplateContextEventArgs");
            a.item("Detail", "ExportedType:WebGroupByRowTemplateContext");
        }
        static d(a) {
            WebGroupByRowTemplateContextEventArgsDescriptionMetadata.b(a);
            a.ac("WebGroupByRowTemplateContextEventArgs", () => new WebGroupByRowTemplateContextEventArgsDescription());
            a.ab("WebGroupByRowTemplateContextEventArgs", WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a);
        }
    }
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(WebGroupByRowTemplateContextEventArgsDescriptionMetadata, 'WebGroupByRowTemplateContextEventArgsDescriptionMetadata');
    WebGroupByRowTemplateContextEventArgsDescriptionMetadata.a = null;
    return WebGroupByRowTemplateContextEventArgsDescriptionMetadata;
})();
